@@ -5,12 +5,13 @@ import os
 import sys
 
 from . import __version__
+from .contours import contours_run
 from .coordinates import coordinates_run
 from .direction import direction_run
 from .path import path_run
+from .segments import segments_run
 
 # from .overlap import overlap_run
-# from .report import report_run
 
 
 def main() -> None:  # pragma: no cover
@@ -27,6 +28,24 @@ def run(argv) -> None:
     )
     subparsers = parser.add_subparsers(dest="subparser_name")
 
+    # -------------------------------
+    # contours sub-command parser
+    # -------------------------------
+    parser_contours = subparsers.add_parser(
+        "contours",
+        help="Contours inspection",
+        description="Contours inspection",
+    )
+    parser_contours.add_argument(
+        "-v", "--version", action="version", version=f"pathins v{__version__}"
+    )
+    parser_contours.add_argument("--nocolor", action="store_true", help="no ANSI color")
+    parser_contours.add_argument("fontpath", type=str, help="font file path")
+    parser_contours.add_argument(
+        "glyphname", type=str, help="glyph name (optional, default=all)", nargs="?"
+    )
+    parser_contours.set_defaults(func=contours_run)
+
     # -------------------------------
     # coordinates sub-command parser
     # -------------------------------
@@ -101,20 +120,20 @@ def run(argv) -> None:
     parser_path.set_defaults(func=path_run)
 
     # -----------------------------
-    # report sub-command parser
+    # segments sub-command parser
     # -----------------------------
-    # parser_report = subparsers.add_parser(
-    #     "report", help="Path reporting", description="Path reporting"
-    # )
-    # parser_report.add_argument(
-    #     "-v", "--version", action="version", version=f"pathins v{__version__}"
-    # )
-    # parser_report.add_argument("--nocolor", action="store_true", help="no ANSI color")
-    # parser_report.add_argument("fontpath", type=str, help="font file path")
-    # parser_report.add_argument(
-    #     "glyphname", type=str, help="glyph name (optional, default=all)", nargs="?"
-    # )
-    # parser_report.set_defaults(func=report_run)
+    parser_segments = subparsers.add_parser(
+        "segments", help="Path segment inspection", description="Path segment inspection"
+    )
+    parser_segments.add_argument(
+        "-v", "--version", action="version", version=f"pathins v{__version__}"
+    )
+    parser_segments.add_argument("--nocolor", action="store_true", help="no ANSI color")
+    parser_segments.add_argument("fontpath", type=str, help="font file path")
+    parser_segments.add_argument(
+        "glyphname", type=str, help="glyph name (optional, default=all)", nargs="?"
+    )
+    parser_segments.set_defaults(func=segments_run)
 
     # -----------------------------
     # Parse args
